#include <vector>
#include <algorithm>
#include <iostream>
#include <set>
#include <cassert>

using namespace std;

const int dx[] = {0, 1, 0, -1},
          dy[] = {1, 0, -1, 0};

int n, m;
vector<string> Mat;

struct DSU {
    vector<int> Link;

    DSU(size_t n) : Link(n, -1) {}

    int Find(int x) {
        if (Link[x] == -1) 
            return x;
        return Link[x] = Find(Link[x]);
    }

    void Union(int a, int b) {
        a = Find(a); b = Find(b);
        if (a == b) return;
        Link[a] = b;
    }
};

vector<vector<int>> CC;
void BuildConnectedComps() {
    auto cell2ind = [&](int a, int b) {
        return a * m + b;
    };

    DSU dsu(n * m);

    for (int i = 0; i < n; ++i) {
        for (int j = 0; j < m; ++j) {
            for (int d = 0; d < 4; ++d) {
                int newi = i + dx[d];
                int newj = j + dy[d];

                if (newi < 0 || newi >= n || newj < 0 || newj >= m)
                    continue;

                if (Mat[i][j] == Mat[newi][newj])
                    dsu.Union(cell2ind(i, j), cell2ind(newi, newj));
            }
        }
    }

    CC.resize(n);
    for (int i = 0; i < n; ++i) {
        CC[i].resize(m);
        for (int j = 0; j < m; ++j) {
            CC[i][j] = dsu.Find(cell2ind(i, j));
        }
    }
}

struct BBox {
    int l = 10000, u = 10000, r = -1, d = -1;

    BBox() {}
    BBox(int l, int u, int r, int d) :
        l(l), u(u), r(r), d(d) {}

    void Include(int i, int j) {
        l = min(l, j);
        r = max(r, j);
        u = min(u, i);
        d = max(d, i);
    }

    bool Inside(BBox oth) {
        if (l < oth.l) return false;
        if (r > oth.r) return false;
        if (u < oth.u) return false;
        if (d > oth.d) return false;
        return true;
    }
};

vector<BBox> boxes;
void ComputeBBoxes() {
    boxes.resize(n * m);

    for (int i = 0; i < n; ++i)
        for (int j = 0; j < m; ++j)
            boxes[CC[i][j]].Include(i, j);
}

vector<vector<int>> Pref;
void CalculatePrefix() {
    Pref.resize(n);
    for (int i = 0; i < n; ++i)
        Pref[i].resize(m);

    for (int i = 0; i < n * m; ++i) {
        if(boxes[i].d != -1)
            Pref[boxes[i].d][boxes[i].r] += 1;
    }


    for (int i = 0; i < n; ++i) {
        for (int j = 0; j < m; ++j) {
            if (i > 0) Pref[i][j] += Pref[i - 1][j];
            if (j > 0) Pref[i][j] += Pref[i][j - 1];
            if (i > 0 && j > 0) Pref[i][j] -= Pref[i - 1][j - 1];
        }
    }
}

vector<int> Freq;

int Compute(BBox box) {
    if (box.u == 0 && box.l == 0) 
        return Pref[box.d][box.r];

    if (box.l == 0) {
        BBox big(0, 0, box.r, box.d),
             small(0, 0, box.r, box.u - 1);

        int ret = Compute(big)
                - Compute(small);

        for (int col = box.l; col <= box.r; ++col) {
            int check = CC[box.u][col];
            if (boxes[check].Inside(big) && !boxes[check].Inside(box)) {
                if (++Freq[check] == 1)
                    ret -= 1;
            }
        }

        for (int col = box.l; col <= box.r; ++col) {
            Freq[CC[box.u][col]] = 0;
        }

        return ret;
    } else {
        BBox big(0, box.u, box.r, box.d),
             small(0, box.u, box.l - 1, box.d);

        int ret = Compute(big)
                - Compute(small);


        for (int row = box.u; row <= box.d; ++row) {
            int check = CC[row][box.l];
            if (boxes[check].Inside(big) && !boxes[check].Inside(box))
                if (++Freq[check] == 1)
                    ret -= 1;
        }

        for (int row = box.u; row <= box.d; ++row) {
            Freq[CC[row][box.l]] = 0;
        }

        return ret;
    }
}

int main() {
    freopen("camere.in", "r", stdin);
    freopen("camere.out", "w", stdout);
    ios_base::sync_with_stdio(false);
    cin.tie(0);

    cin >> n >> m;

    Mat.resize(n);
    for (int i = 0; i < n; ++i) {
        cin >> Mat[i];
    }

    BuildConnectedComps();
    ComputeBBoxes();
    CalculatePrefix();
    Freq.resize(n * m);

    int q;
    cin >> q;
    while(q--) {
        int l, u, r, d;
        cin >> u >> l >> d >> r;
        BBox box(l - 1, u - 1, r - 1, d - 1);
        int ret = Compute(box);

        for (int row = box.u; row <= box.d; ++row) {
            if (!boxes[CC[row][box.l]].Inside(box))
                if (++Freq[CC[row][box.l]] == 1)
                    ret += 1;
            if (!boxes[CC[row][box.r]].Inside(box))
                if (++Freq[CC[row][box.r]] == 1)
                    ret += 1;
        }

        for (int col = box.l; col <= box.r; ++col) {
            if (!boxes[CC[box.u][col]].Inside(box))
                if (++Freq[CC[box.u][col]] == 1)
                    ret += 1;
            if (!boxes[CC[box.d][col]].Inside(box))
                if (++Freq[CC[box.d][col]] == 1)
                    ret += 1;
        }

        for (int row = box.u; row <= box.d; ++row) {
            Freq[CC[row][box.l]] = 0;
            Freq[CC[row][box.r]] = 0;
        }

        for (int col = box.l; col <= box.r; ++col) {
            Freq[CC[box.u][col]] = 0;
            Freq[CC[box.d][col]] = 0;
        }

        cout << ret  << '\n';
    }



    return 0;
}