/*Patrick Catalin Alexandru Sava
Atooom Industry and Resources SRL
University of Bucharest
Expected : 100 points*/

#include <fstream>
#include <vector>
#include <cassert>
#include <set>

using namespace std ;

ifstream cin ("camere.in") ;
ofstream cout ("camere.out") ;

const int MAX = 5e3 + 14 ;

int dx [] = {1, -1, 0, 0} ;
int dy [] = {0, 0, 1, -1} ;

char mat [MAX][MAX] ;
bool viz [MAX][MAX] ;

bool between (int a, int inf, int sup)
{
	return a >= inf and a <= sup ;
}

bool inside (int i, int j, int n, int m) {
	return i >= 1 and i <= n and j >= 1 and j <= m;
}

void fill (int i, int j, int n, int m, char target, vector <pair<int, int>> &pos) {
	if (viz [i][j] == true) return ;
	if (!inside(i, j, n, m)) return ;
	if (mat [i][j] != target) return ;
	viz [i][j] = true ;
	pos.push_back ({i, j}) ;
	for (int k = 0; k <= 3; ++ k) {
		int x = i + dx [k] ;
		int y = j + dy [k] ;
		fill (x, y, n, m, target, pos) ;
	}
}

class Corners
{
public:
	Corners() {
		upper_left = {1e9, 1e9} ;
		lower_right = {0, 0} ;
	}
	pair <int, int> upper_left ;
	pair <int, int> lower_right ;
	void Compute (pair <int, int> &other) {
		upper_left.first = min (upper_left.first, other.first) ;
		upper_left.second = min (upper_left.second, other.second) ;
		lower_right.first = max (lower_right.first, other.first) ;
		lower_right.second = max (lower_right.second, other.second) ;
	}
};

int End [MAX][MAX] ;

int chambers [MAX][MAX] ;

void erase (vector <bool> &uz, int &n, vector <int> &who) {
	for (int i = 1 ; i <= n ; ++ i) {
		uz [who[i]] = false ;
	}
}

void increase (int x, int &cnt, vector <bool> &uz, int &n, vector <int> &who) {
	if (uz [x]) return ;
	uz [x] = true ;
	cnt += 1 ;
	++ n ;
	who [n] = x ;
}

int pref (int i, int j) {
	return End [i][j] ;
}

int slice_pref (int a, int i, int j, vector <Corners> &corners, vector <bool> &uz, vector <int> &who) {
	assert (a <= i) ;
	int sol = pref (i, j) - pref (a - 1, j) ;
	// cout << pref (a - 1, j) << ' ' << pref (i, j) << '\n' ;
	int n = 0 ;
	for (int k = 1; k <= j; ++ k) {
		if (uz[chambers[a][k]] == false) {
			if (corners[chambers[a][k] - 1].lower_right.second <= j and corners[chambers[a][k] - 1].upper_left.first < a
			        and corners[chambers[a][k] - 1].lower_right.first <= i) {
				sol -= 1 ;
			}
			uz[chambers[a][k]] = true ;
			who [++n] = chambers[a][k] ;
		}
	}
	erase (uz, n, who) ;
	return sol ;
}

int rectangle (int x1, int y1, int x2, int y2, vector <Corners> &corners, vector <bool> &uz, vector <int> &who) {
	assert (x1 <= x2) ;
	assert (y1 <= y2) ;
	int sol = slice_pref (x1, x2, y2, corners, uz, who) ;
	sol -= slice_pref (x1, x2, y1 - 1, corners, uz, who) ;
	int n = 0 ;
	for (int k = x1; k <= x2; ++ k) {
		if (uz[chambers[k][y1]] == false) {
			if (corners[chambers[k][y1] - 1].lower_right.first <= x2
			        and corners[chambers[k][y1] - 1].upper_left.first >= x1 and corners[chambers[k][y1] - 1].upper_left.second < y1
			        and corners[chambers[k][y1] - 1].lower_right.second <= y2) {
				sol -= 1 ;
			}
			uz[chambers[k][y1]] = true ;
			who [++n] = chambers[k][y1] ;
		}
	}
	erase (uz, n, who) ;
	return sol ;
}

int main(int argc, char const *argv[])
{
	int n, m;
	assert(cin >> n >> m) ;
	assert (between(n, 1, MAX)) ;
	assert (between(m, 1, MAX)) ;
	for (int i = 1 ; i <= n; ++ i) {
		assert(cin >> (mat [i] + 1)) ;
	}
	vector <vector<pair<int, int>>> positions ;
	for (int i = 1 ; i <= n ; ++ i) {
		for (int j = 1 ; j <= m; ++ j) {
			if (viz [i][j] == false) {
				positions.push_back(vector <pair<int, int>> ()) ;
				assert(between((int)mat[i][j], (int)'a', (int)'z')) ;
				fill (i, j, n, m, mat [i][j], positions.back()) ;
			}
		}
	}
	int nrAreas = positions.size() ;
	vector <Corners> corners (nrAreas) ;
	for (int i = 0 ; i < nrAreas; ++ i) {
		for (auto x : positions[i]) {
			corners[i].Compute(x) ;
			chambers[x.first][x.second] = i + 1 ;
		}
	}
	for (int i = 0; i < nrAreas; ++ i) {
		End [corners[i].lower_right.first][corners[i].lower_right.second] += 1 ; // then partial sums
	}
	for (int i = 1 ; i <= n ; ++ i) {
		for (int j = 1 ; j <= m; ++ j) {
			End [i][j] = End [i][j] + End [i - 1][j] + End [i][j - 1] - End [i - 1][j - 1];
		}
	}
	vector <bool> uz (nrAreas, false) ;
	vector <int> choosen (nrAreas, 0) ;
	int howmany = 0 ;
	int nrRectangles ;
	assert (cin >> nrRectangles) ;
	while (nrRectangles --) {
		int x1, y1, x2, y2 ;
		assert(cin >> x1 >> y1 >> x2 >> y2) ;
		assert (x1 <= x2) ;
		assert (y1 <= y2) ;
		assert (between(x1, 1, n)) ;
		assert (between(x2, 1, n)) ;
		assert (between(y1, 1, m)) ;
		assert (between(y2, 1, m)) ;
		int Totally_Included = rectangle (x1, y1, x2, y2, corners, uz, choosen) ;
		int cnt = 0 ;
		for (int j = y1; j <= y2; ++ j) {
			if (chambers [x1][j] == chambers [x1 - 1][j]) {
				increase(chambers[x1][j], cnt, uz, howmany, choosen) ;
			}
			if (chambers [x2][j] == chambers [x2 + 1][j]) {
				increase(chambers[x2][j], cnt, uz, howmany, choosen) ;
			}
		}
		for (int i = x1 ; i <= x2 ; ++ i) {
			if (chambers [i][y1] == chambers [i][y1 - 1]) {
				increase(chambers [i][y1], cnt, uz, howmany, choosen) ;
			}
			if (chambers [i][y2] == chambers [i][y2 + 1]) {
				increase(chambers [i][y2], cnt, uz, howmany, choosen) ;
			}
		}
		for (int i = 1; i <= howmany; ++ i) {
			uz [choosen[i]] = false ;
		}
		howmany = 0 ;
		int Partial_Included = cnt ;
		cout << Totally_Included + Partial_Included << '\n' ;
	}
	return 0;
}