/**
 * visanr
 * O(N ^ 2 + Q * N * log N)
 */

#include <bits/stdc++.h>
using namespace std;

const int kNmax = 2010;
const int kInf = 0x3f3f3f3f;
const int kDx[4] = {-1, 0, 0, 1};
const int kDy[4] = {0, -1, 1, 0};
const int DEBUG = 0;

int n, m, q, r1, r2, c1, c2;
char mat[kNmax][kNmax];
int min_x[kNmax * kNmax];
int max_x[kNmax * kNmax];
int min_y[kNmax * kNmax];
int max_y[kNmax * kNmax];
int cnt[kNmax][kNmax], cnt_lr[kNmax][kNmax];
int hsum[kNmax][kNmax], vsum[kNmax][kNmax];
int idx[kNmax][kNmax];
bool used_room[kNmax * kNmax];

void fill(int sx, int sy, int index) {
	queue<pair<int, int> > q;
	q.push({sx, sy});
	idx[sx][sy] = index;

	while (!q.empty()) {
		int x, y;
		std::tie(x, y) = q.front();
		q.pop();

		min_x[index] = min(min_x[index], x);
		max_x[index] = max(max_x[index], x);
		min_y[index] = min(min_y[index], y);
		max_y[index] = max(max_y[index], y);

		for (int i = 0; i < 4; i++) {
			int nx = x + kDx[i];
			int ny = y + kDy[i];

			if (1 <= nx && nx <= n && 1 <= ny && ny <= m && idx[nx][ny] == 0 && mat[x][y] == mat[nx][ny]) {
				q.push({nx, ny});
				idx[nx][ny] = index;
			}
		}
	}
}

int main() {
	freopen("camere.in", "r", stdin);
	freopen("camere.out", "w", stdout);

	assert(scanf("%d %d\n", &n, &m) == 2);
	assert(1 <= n && n <= 2000);
	assert(1 <= m && m <= 2000);
	for (int i = 1; i <= n; i++) {
		gets(mat[i] + 1);
	}

	int index = 0;
	for (int i = 1; i <= n; i++) {
		for (int j = 1; j <= m; j++) {
			if (idx[i][j] == 0) {
				++index;
				min_x[index] = min_y[index] = kInf;
				max_x[index] = max_y[index] = -kInf;
				fill(i, j, index);
			}
		}
	}

	for (int i = 1; i <= index; i++) {
		cnt[min_x[i] + 1][min_y[i] + 1]++;
		cnt[max_x[i] + 1][min_y[i] + 1]--;
		cnt[min_x[i] + 1][max_y[i] + 1]--;
		cnt[max_x[i] + 1][max_y[i] + 1]++;

		cnt_lr[max_x[i]][max_y[i]]++;
		hsum[max_x[i]][min_y[i] + 1]++;
		hsum[max_x[i]][max_y[i] + 1]--;
		vsum[min_x[i] + 1][max_y[i]]++;
		vsum[max_x[i] + 1][max_y[i]]--;
	}

	for (int i = 1; i <= n; i++) {
		for (int j = 1; j <= m; j++) {
			hsum[i][j] += hsum[i][j - 1];
			vsum[i][j] += vsum[i - 1][j];
			cnt[i][j] = cnt[i][j] + cnt[i - 1][j] + cnt[i][j - 1] - cnt[i - 1][j - 1];
			cnt_lr[i][j] = cnt_lr[i][j] + cnt_lr[i - 1][j] + cnt_lr[i][j - 1] - cnt_lr[i - 1][j - 1];
		}
	}

	for (int i = 1; i <= n; i++) {
		for (int j = 1; j <= m; j++) {
			vsum[i][j] += vsum[i][j - 1];
			hsum[i][j] += hsum[i - 1][j];
		}
	}

	assert(scanf("%d", &q) == 1);
	assert(0 <= q && q <= 5000);

	for (; q; q--) {
		assert(scanf("%d %d %d %d", &r1, &c1, &r2, &c2) == 4);
		assert(1 <= r1 && r1 <= r2 && r2 <= n);
		assert(1 <= c1 && c1 <= c2 && c2 <= m);

		int ans = 0;
		ans += cnt_lr[r2][c2] - cnt_lr[r1 - 1][c2] - cnt_lr[r2][c1 - 1] + cnt_lr[r1 - 1][c1 - 1];
		ans -= vsum[r1][c2] - vsum[r1][c1 - 1];
		ans -= hsum[r2][c1] - hsum[r1 - 1][c1];
		ans += cnt[r1][c1];

		vector<int> rooms;
		for (int i = c1; i <= c2; i++) {
			if (mat[r1][i] == mat[r1 - 1][i] && !used_room[ idx[r1][i] ]) {
				used_room[ idx[r1][i] ] = 1;
				rooms.push_back(idx[r1][i]);
			}
			if (mat[r2][i] == mat[r2 + 1][i] && !used_room[ idx[r2][i] ]) {
				used_room[ idx[r2][i] ] = 1;
				rooms.push_back(idx[r2][i]);
			}
		}
		for (int i = r1; i <= r2; i++) {
			if (mat[i][c1] == mat[i][c1 - 1] && !used_room[ idx[i][c1] ]) {
				used_room[ idx[i][c1] ] = 1;
				rooms.push_back(idx[i][c1]);
			}
			if (mat[i][c2] == mat[i][c2 + 1] && !used_room[ idx[i][c2] ]) {
				used_room[ idx[i][c2] ] = 1;
				rooms.push_back(idx[i][c2]);
			}
		}

		ans += rooms.size();
		for (int room : rooms) {
			used_room[room] = 0;
		}

		printf("%d\n", ans);
	}

	return 0;
}