#include <iostream>
#include <fstream>
#include <algorithm>
#include <vector>
#include <cassert>

using namespace std;

static const int kModulo = 666013;

int pow(int a, int b) {
    if (b == 0)
        return 1;
    if (b % 2)
        return 1LL * pow(a, b - 1) * a % kModulo;
    int v = pow(a, b / 2);
    return 1LL * v * v % kModulo;
}

struct Rectangle {
    int x1, y1, x2, y2;

    int max() const {
        return ::max(x2, y2);
    }

    bool empty() const {
        return x1 > x2 || y1 > y2;
    }

    void flip() {
        swap(x1, y1);
        swap(x2, y2);
    }
};

istream& operator>>(istream& input, Rectangle& r) {
    input >> r.x1 >> r.y1 >> r.x2 >> r.y2;
    return input;
}

Rectangle intersect(Rectangle A, Rectangle B) {
    return Rectangle{max(A.x1, B.x1), max(A.y1, B.y1), min(A.x2, B.x2), min(A.y2, B.y2)};
}

int abs(int x) {
    if (x < 0)
        return -x;
    return x;
}

template<class Comb>
int ways(Rectangle A, int x, int y, Comb comb) {
    if (A.empty())
        return 0;
    // it's a sum of combinations
    // of form C(dx + dy, dx) for all dx between (A, B) and all dy between (C, D)
    int a = abs(A.x1 - x);
    int b = abs(A.x2 - x);
    int c = abs(A.y1 - y);
    int d = abs(A.y2 - y);
    if (a > b)
        swap(a, b);
    if (c > d)
        swap(c, d);

    // C(i + j, i) for i in (a, b) for j in (c, d)
    // if i did well it's C(a + c, a) + C(b + d + 2, b + 1) - C(a + d + 1, a) - C(b + 1 + c, c)
    int aux = comb(a + c, a) + comb(b + d + 2, b + 1) - comb(a + d + 1, a) - comb(b + 1 + c, c);
    aux %= kModulo;
    if (aux < 0)
        aux += kModulo;
    return aux;
}

int main() {
    ifstream cin("manhattan.in");
    ofstream cout("manhattan.out");

    Rectangle A, B; assert(cin >> A >> B);
    assert(0 <= A.x1 && A.x1 <= A.x2 && A.x2 <= 100 * 1000);
    assert(0 <= A.y1 && A.y1 <= A.y2 && A.y2 <= 100 * 1000);
    assert(0 <= B.x1 && B.x1 <= B.x2 && B.x2 <= 100 * 1000);
    assert(0 <= B.y1 && B.y1 <= B.y2 && B.y2 <= 100 * 1000);
    assert(intersect(A, B).empty());
    if (A.x1 > B.x2)
        swap(A, B);
    if (A.y1 > B.y2)
        swap(A, B);
    if (A.y2 < B.y1) {
        A.flip();
        B.flip();
    }

    assert(A.x2 < B.x1);
    int max_coord = max(A.max(), B.max());
    vector<int> fact(2 * max_coord + 4, 1);
    for (int i = 1; i < 2 * max_coord + 4; ++i)
        fact[i] = 1LL * fact[i - 1] * i % kModulo;
    vector<int> ifact(2 * max_coord + 4, 1);
    ifact[2 * max_coord + 3] = pow(fact[2 * max_coord + 3], kModulo - 2);
    for (int i = 2 * max_coord + 3; i > 0; --i)
        ifact[i - 1] = 1LL * ifact[i] * i % kModulo;
    auto comb = [&](int N, int K) {
        int aux = 1LL * fact[N] * ifact[K] % kModulo;
        return 1LL * aux * ifact[N - K] % kModulo;
    };

    int answer = 0;
    for (int through = min(A.y1, B.y1); through <= max(A.y2, B.y2); ++through) {
        // we need 6 values, left-down, left, left-up, right-down, right-middle, right-up
        int left_down = ways(intersect(A, Rectangle{0, 0, A.x2, through - 1}), A.x2, through, comb);
        int left = ways(intersect(A, Rectangle{0, through, A.x2, through}), A.x2, through, comb);
        int left_up = ways(intersect(A, Rectangle{0, through + 1, A.x2, max_coord}), A.x2, through, comb);

        int right_down = ways(intersect(B, Rectangle{A.x2 + 1, 0, max_coord, through - 1}), A.x2 + 1, through, comb);
        int right = ways(intersect(B, Rectangle{A.x2 + 1, through, max_coord, through}), A.x2 + 1, through, comb);
        int right_up = ways(intersect(B, Rectangle{A.x2 + 1, through + 1, max_coord, max_coord}), A.x2 + 1, through, comb);

        answer = (answer + 1LL * left_down * (right + right_up)) % kModulo;
        answer = (answer + 1LL * left * (right_down + right + right_up)) % kModulo;
        answer = (answer + 1LL * left_up * (right_down + right)) % kModulo;
    }

    cout << answer << "\n";
}
